# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from ..test_run_response import TestRunResponse

__all__ = ["RunTriggerResponse"]

RunTriggerResponse: TypeAlias = List[TestRunResponse]
